Method: Player::Power#state
- Defined in:
- lib/ruby-player/power.rb
#state ⇒ Hash (readonly)
Power state
:valid status bits. The driver will set the bits to indicate which fields it is using. Bitwise-and with PLAYER_POWER_MASK_X values to see which fields are being set.
:volts Battery voltage [V].
:percent Percent of full charge [%].
:joules Energy stored [J].
:watts Estimated current energy consumption (negative values) or aquisition (positive values) [W].
:charging Charge exchange status: if 1, the device is currently receiving charge from another energy device
34 35 36 |
# File 'lib/ruby-player/power.rb', line 34 def state @state end |